@@ -37,8 +37,11 @@ from sequana.stats import evenness
 
 from easydev import do_profile, TempFile, Progress
 
-from sequana import logger
-logger.name = __name__
+import colorlog
+logger = colorlog.getLogger(__name__)
+
+
+
 
 __all__ = ["GenomeCov", "ChromosomeCov", "DoubleThresholds"]
 
