@@ -177,7 +177,6 @@ class RNADiffAnalysis:
         self.design = RNADesign(design_file, sep=sep_design, reference=reference)
         self.comparisons = comparisons if comparisons else self.design.comparisons
 
-
         _conditions = {x for comp in self.comparisons for x in comp}
         if not keep_all_conditions:
             self.design.keep_conditions(_conditions)
@@ -273,12 +272,14 @@ Design overview:\n\
         except ValueError:
             counts = FeatureCount(self.usr_counts).df
 
+        Ncounts = len(counts)
         if self.minimum_mean_reads_per_gene > 0:
             logger.info(f"{len(counts)} annotated feature to be processed")
-        counts = counts[counts.mean(axis=1) > self.minimum_mean_reads_per_gene]
-        if self.minimum_mean_reads_per_gene > 0:
-            logger.info(f"Keeping {len(counts)} features after removing low "
-                f"counts below {self.minimum_mean_reads_per_gene} on average")
+        counts = counts[counts.mean(axis=1) >= self.minimum_mean_reads_per_gene]
+        logger.info(
+            f"Read {Ncounts} counts. Keeping {len(counts)} features after removing low "
+            f"counts below {self.minimum_mean_reads_per_gene} on average"
+        )
 
         # filter count based on the design and the comparisons provide in the
         # constructor so that columns match as expected by a DESeq2 analysis.
@@ -565,7 +566,7 @@ class RNADiffTable:
         try:
             bax.set_xlabel("fold change")
             bax.set_ylabel("log10 adjusted p-value")
-        except:
+        except Exception:
             bax.xlabel("fold change")
             bax.ylabel("log10 adjusted p-value")
 
@@ -574,12 +575,12 @@ class RNADiffTable:
         limit = max(m1, m2)
         try:
             bax.set_xlim([-limit, limit])
-        except:
+        except Exception:
             bax.xlim([-limit, limit])
         try:
             y1, _ = bax.get_ylim()
             ax1 = bax.axs[0].set_ylim([br2, y1[1] * 1.1])
-        except:
+        except Exception:
             y1, y2 = bax.ylim()
             bax.ylim([0, y2])
         bax.axhline(
@@ -645,7 +646,7 @@ class RNADiffTable:
         pylab.ylabel("Occurences", fontsize=fontsize)
         try:
             pylab.tight_layout()
-        except:
+        except Exception:
             pass
 
     def plot_padj_hist(self, bins=60, fontsize=16):
@@ -655,7 +656,7 @@ class RNADiffTable:
         pylab.ylabel("Occurences", fontsize=fontsize)
         try:
             pylab.tight_layout()
-        except:
+        except Exception:
             pass
 
 
@@ -800,13 +801,15 @@ class RNADiffResults:
         if self.annot_cols is None:
             lol = [
                 list(x.keys())
-                for x in gff.df.query("type==@self.fc_feature")["attributes"].values
+                for x in gff.df.query("genetic_type==@self.fc_feature")[
+                    "attributes"
+                ].values
             ]
             annot_cols = sorted(list(set([x for item in lol for x in item])))
         else:
             annot_cols = self.annot_cols
 
-        df = gff.df.query("type == @self.fc_feature").loc[:, annot_cols]
+        df = gff.df.query("genetic_type == @self.fc_feature").loc[:, annot_cols]
         df.drop_duplicates(inplace=True)
 
         df.set_index(self.fc_attribute, inplace=True)
@@ -1039,7 +1042,7 @@ class RNADiffResults:
         pylab.xticks(rotation=rotation, ha="right", fontsize=xticks_fontsize)
         try:
             pylab.tight_layout()
-        except:
+        except Exception:
             pass
 
     def plot_percentage_null_read_counts(self, fontsize=None, xticks_fontsize=None):
@@ -1079,7 +1082,10 @@ class RNADiffResults:
         pylab.xticks(rotation=45, ha="right", fontsize=xticks_fontsize)
         pylab.ylabel("Proportion of null counts (%)")
         pylab.grid(True, zorder=0)
-        pylab.tight_layout()
+        try:
+            pylab.tight_layout()
+        except Exception:
+            pass
 
     def plot_pca(
         self,
@@ -1089,7 +1095,7 @@ class RNADiffResults:
         max_features=500,
         genes_to_remove=[],
         fontsize=10,
-        adjust=True
+        adjust=True,
     ):
 
         """
@@ -1112,6 +1118,7 @@ class RNADiffResults:
             r.plot_pca(colors=colors)
         """
         from sequana.viz import PCA
+
         # Get most variable genes (n=max_features)
         top_features = (
             self.counts_vst.var(axis=1)
@@ -1178,7 +1185,7 @@ class RNADiffResults:
                 colors=self.design_df.group_color,
                 max_features=max_features,
                 fontsize=fontsize,
-                adjust=adjust
+                adjust=adjust,
             )
 
         return variance
@@ -1259,24 +1266,31 @@ class RNADiffResults:
         )
         pylab.yticks(fontsize=xticks_fontsize)
 
-        for idx, rect in enumerate(p):
-            pylab.text(
-                2,  # * rect.get_height(),
-                idx,  # rect.get_x() + rect.get_width() / 2.0,
-                df.gene_id.iloc[idx],
-                ha="center",
-                va="center",
-                rotation=0,
-                zorder=20,
-                fontsize=xticks_fontsize
-            )
-
         self._format_plot(
             # title="Counts monopolized by the most expressed gene",
             # xlabel="Sample",
             xlabel="Percent of total reads",
-            fontsize=xticks_fontsize
+            fontsize=xticks_fontsize,
         )
+
+        ax = pylab.gca()
+        ax2 = ax.twinx()
+        N = len(df)
+        ax2.set_yticks([x + 0.5 for x in range(N)])
+        if N <= 12:
+            fontdict = {"fontsize": 12}
+        elif N <= 24:
+            fontdict = {"fontsize": 10}
+        else:
+            fontdict = {"fontsize": 8}
+
+        ax2.set_yticklabels(list(df.gene_id.values), fontdict=fontdict)
+        ax2.tick_params(
+            axis="y", grid_linewidth=0
+        )  # this is for the case seaborn is used
+
+        pylab.sca(ax)
+
         pylab.tight_layout()
 
     def plot_dendogram(
@@ -1321,10 +1335,18 @@ class RNADiffResults:
         d.category = self.design_df[self.condition].map(group_conv).to_dict()
         d.plot()
 
-    def plot_boxplot_rawdata(self, fliersize=2, linewidth=2, rotation=0,
-            fontsize=None, xticks_fontsize=None, **kwargs):
+    def plot_boxplot_rawdata(
+        self,
+        fliersize=2,
+        linewidth=2,
+        rotation=0,
+        fontsize=None,
+        xticks_fontsize=None,
+        **kwargs,
+    ):
 
         import seaborn as sbn
+
         if fontsize is None:
             fontsize = self.fontsize
         if xticks_fontsize is None:
@@ -1344,10 +1366,18 @@ class RNADiffResults:
         self._format_plot(ylabel="Raw count distribution", fontsize=xticks_fontsize)
         pylab.tight_layout()
 
-    def plot_boxplot_normeddata(self, fliersize=2, linewidth=2, rotation=0,
-        fontsize=None, xticks_fontsize=None, **kwargs):
+    def plot_boxplot_normeddata(
+        self,
+        fliersize=2,
+        linewidth=2,
+        rotation=0,
+        fontsize=None,
+        xticks_fontsize=None,
+        **kwargs,
+    ):
 
         import seaborn as sbn
+
         if fontsize is None:
             fontsize = self.fontsize
         if xticks_fontsize is None:
