@@ -30,7 +30,7 @@ from sequana.utils import config
 from sequana import version
 from sequana.iem import IEM
 from sequana import GFF3
-from sequana import FastQ
+from sequana import FastQ, FastA
 from sequana.rnadiff import RNADiffAnalysis, RNADesign
 
 import colorlog
@@ -139,6 +139,60 @@ def main(**kwargs):
     pass
 
 
+# =====================================================================================
+# fastq-related tools
+# =====================================================================================
+@main.command()
+@click.argument("filename", type=click.STRING, nargs=-1)
+@click.option(
+    "-o",
+    "--output",
+    help="filename where to save results. to be used with --head, --tail",
+)
+@click.option("--count-sequences", is_flag=True)
+@click.option("--head", type=click.INT, help="number of sequences to extract from the head")
+@click.option("--merge", is_flag=True, help="merge all compressed input fastq files into a single file")
+@click.option("--tail", type=click.INT, help="number of reads to extract from the tail")
+@click.option("--explode", is_flag=True, help="Create a fasta file for each sequence found in the original files")
+def fasta(**kwargs):
+    """Set of useful utilities for FastA manipulation.
+
+    """
+    filenames = kwargs["filename"]
+    # users may provide a wildcards such as "A*gz" or list of files.
+    if len(filenames) == 1:
+        # if existing files or glob, a glob would give the same answer.
+        filenames = glob.glob(filenames[0])
+    for filename in filenames:
+        os.path.exists(filename)
+
+    # could be simplified calling count_reads only once
+    if kwargs["count_sequences"]:
+        for filename in filenames:
+            f = FastA(filename)
+            Nreads = len(f)
+            print(f"Number of reads in {filename}: {Nreads}")
+    elif kwargs["merge"]:
+        # merge all input files (assuming gz extension)
+        extensions = [filename.split(".")[-1] for filename in filenames]
+        if set(extensions) != set(["gz"]):
+            raise ValueError("Your input FastA files must be zipped")
+        output_filename = kwargs["output"]
+        if output_filename is None:
+            logger.error("You must use --output filename.gz")
+            sys.exit(1)
+        if output_filename.endswith(".gz") is False:
+            raise ValueError("your output file must end in .gz")
+        p1 = subprocess.Popen(["zcat"] + list(filenames), stdout=subprocess.PIPE)
+        fout = open(output_filename, "wb")
+        p2 = subprocess.run(["pigz"], stdin=p1.stdout, stdout=fout)
+    elif kwargs["explode"]:
+        for filename in filenames:
+            f = FastA(filename)
+            f.explode()
+
+
+
 # =====================================================================================
 # fastq-related tools
 # =====================================================================================
@@ -151,7 +205,7 @@ def main(**kwargs):
 )
 @click.option("--count-reads", is_flag=True)
 @click.option("--head", type=click.INT, help="number of reads to extract from the head")
-@click.option("--merge", is_flag=True)
+@click.option("--merge", is_flag=True, help="merge all compressed input fastq files into a single file")
 @click.option("--tail", type=click.INT, help="number of reads to extract from the tail")
 def fastq(**kwargs):
     """Set of useful utilities for FastQ manipulation.
@@ -159,7 +213,6 @@ def fastq(**kwargs):
     Input file can be gzipped or not. The --output-file
 
     """
-
     filenames = kwargs["filename"]
     # users may provide a wildcards such as "A*gz" or list of files.
     if len(filenames) == 1:
@@ -201,7 +254,6 @@ def fastq(**kwargs):
         p1 = subprocess.Popen(["zcat"] + list(filenames), stdout=subprocess.PIPE)
         fout = open(output_filename, "wb")
         p2 = subprocess.run(["pigz"], stdin=p1.stdout, stdout=fout)
-
     else:  # pragma: no cover
         print("Use one of the commands")
 
@@ -247,7 +299,7 @@ def samplesheet(**kwargs):
 @click.option(
     "--module",
     required=False,
-    type=click.Choice(["bamqc", "bam", "fasta", "fastq", "gff"]),
+    type=click.Choice(["bamqc", "bam", "fasta", "fastq", "gff", "vcf"]),
 )
 def summary(**kwargs):
     """Create a HTML report for various type of NGS formats.
@@ -322,11 +374,23 @@ def summary(**kwargs):
 
         for filename in names:
             ff = GFF3(filename)
-            print("#filename: {}".format(filename))
+            print(f"#filename: {filename}")
             print("#Number of entries per genetic type:")
-            print(ff.df.value_counts("type").to_string())
+            print(ff.df.value_counts("genetic_type").to_string())
             print("#Number of duplicated attribute (if any) per attribute:")
-            ff.get_duplicated_attributes_per_type()
+            ff.get_duplicated_attributes_per_genetic_type()
+    elif module == "vcf":
+        from sequana.freebayes_vcf_filter import VCF_freebayes
+
+        for filename in names:
+            print(f"#filename: {filename}")
+            vcf = VCF_freebayes(filename)
+            columns = ("chr", 'position', 'depth', 'reference', 'alternative',
+                       "freebayes_score", 'strand_balance', 'frequency')
+            print(",".join(columns))
+            for variant in vcf.get_variants():
+                resume = variant.resume
+                print(",".join([str(resume[col]) for col in columns]))
 
 
 # =====================================================================================
@@ -812,9 +876,9 @@ def feature_counts(**kwargs):
 @click.option(
     "--annotation-attribute",
     type=click.STRING,
-    # required=True,
     default="Name",
-    help="a valid taxon identifiers",
+    show_default=True,
+    help="a valid attribute to be used to map on KEGG database",
 )
 @click.option(
     "--kegg-name",
@@ -864,6 +928,7 @@ command""",
     "--max-pathways",
     type=click.INT,
     default=40,
+    show_default=True,
     help="""Max number of pathways to show (most enriched)""",
 )
 @click.option(
@@ -875,10 +940,8 @@ command""",
 @click.option("--output-directory", default="enrichment_kegg")
 @common_logger
 def enrichment_kegg(**kwargs):
-    """Create a HTML report for KEGG enrichdvarious sequana out
-
+    """Create a HTML report showing KEGG enriched pathways
     \b
-    * enrichment: the output of RNADiff pipeline
 
     Example for the enrichment module:
 
@@ -886,11 +949,10 @@ def enrichment_kegg(**kwargs):
 
     The KEGG pathways are loaded and it may take time. Once done, they are saved
     in kegg_pathways/organism and be loaded next time:
+    \b
 
-        sequana enrichment-kegg rnadiff/rnadiff.csv
-            --log2-foldchange-cutoff 2 \
-            --kegg-name lbi\
-            --annotation file.gff
+        sequana enrichment-kegg rnadiff/rnadiff.csv --log2-foldchange-cutoff 2 \\
+            --kegg-name lbi --annotation-attribute file.gff
 
 
     """
