@@ -23,8 +23,9 @@ import sys
 
 from sequana.lazy import vcf
 
-from sequana import logger
-logger.name = __name__
+import colorlog
+logger = colorlog.getLogger(__name__)
+
 
 
 __all__ = ["VCFBase"]
